@@ -40,6 +40,9 @@
 #include <libxml/entities.h>
 #include <libxml/HTMLparser.h>
 #include <glib.h>
+#include <pango/pango-types.h>
+#include <gtk/gtk.h>
+
 #include <sys/stat.h>
 #include <string.h>
 #include <locale.h>
@@ -95,7 +98,7 @@ void addToHTMLBuffer(gchar **buffer, const gchar *string) {
    can be NULL) to to_encoding, frees the original string and 
    returns the result */
 gchar * convertCharSet(gchar * from_encoding, gchar * to_encoding, gchar * string) {
-	gint	bw, br;
+	gsize	bw, br;
 	gchar	*new = NULL;
 	GError *err = NULL;
 
@@ -179,7 +182,7 @@ typedef struct {
 	gint	length;
 } result_buffer;
 
-void unhtmlizeHandleCharacters (void *user_data, const xmlChar *string, int length) {
+static void unhtmlizeHandleCharacters (void *user_data, const xmlChar *string, int length) {
 	result_buffer	*buffer = (result_buffer *)user_data;
 	gint 		old_length;
 
@@ -191,7 +194,7 @@ void unhtmlizeHandleCharacters (void *user_data, const xmlChar *string, int leng
 
 }
 
-void _unhtmlize(gchar *string, gchar *result, result_buffer *buffer) {
+static void _unhtmlize(gchar *string, result_buffer *buffer) {
 	htmlParserCtxtPtr	ctxt;
 	htmlSAXHandlerPtr	sax_p = g_new0(htmlSAXHandler, 1);
  	sax_p->characters = unhtmlizeHandleCharacters;
@@ -201,7 +204,7 @@ void _unhtmlize(gchar *string, gchar *result, result_buffer *buffer) {
  	g_free(sax_p);
 }
 
-void _unxmlize(gchar *string, gchar *result, result_buffer *buffer) {
+static void _unxmlize(gchar *string, result_buffer *buffer) {
 	xmlParserCtxtPtr	ctxt;
 	xmlSAXHandler	*sax_p = g_new0(xmlSAXHandler, 1);
  	sax_p->characters = unhtmlizeHandleCharacters;
@@ -215,7 +218,7 @@ void _unxmlize(gchar *string, gchar *result, result_buffer *buffer) {
    a string without any entities or tags containing all
    text nodes of the given HTML string. The original 
    string will be freed. */
-static gchar * unmarkupize(gchar *string, void(*parse)(gchar *string, gchar *result, result_buffer *buffer)) {
+static gchar * unmarkupize(gchar *string, void(*parse)(gchar *string, result_buffer *buffer)) {
 	gchar			*result;
 	result_buffer		*buffer;
 	
@@ -229,7 +232,7 @@ static gchar * unmarkupize(gchar *string, void(*parse)(gchar *string, gchar *res
 		return string;
 
 	buffer = g_new0(result_buffer, 1);
-	parse(string, result, buffer);
+	parse(string, buffer);
 	result = buffer->data;
 	g_free(buffer);
  
@@ -725,6 +728,35 @@ xmlChar * common_build_url(const gchar *url, const gchar *baseURL) {
 	return absURL;
 }
 
+const gchar * common_get_direction_mark(gchar *text) {
+	PangoDirection		pango_direction = PANGO_DIRECTION_NEUTRAL;
+	GtkTextDirection	gtk_direction;
+	
+	if(text)
+		pango_direction = pango_find_base_dir(text, -1);
+		
+	switch(pango_direction) {
+		case PANGO_DIRECTION_LTR:
+			gtk_direction = GTK_TEXT_DIR_LTR;
+			break;
+		case PANGO_DIRECTION_RTL:
+			gtk_direction = GTK_TEXT_DIR_RTL;
+			break;
+		default:
+			gtk_direction = gtk_widget_get_default_direction();
+			break;
+	}
+
+	switch(gtk_direction) {
+		case GTK_TEXT_DIR_RTL: 
+			return "\342\200\217"; /* U+200F RIGHT-TO-LEFT MARK */
+		case GTK_TEXT_DIR_LTR: 
+			return "\342\200\216"; /* U+200E LEFT-TO-RIGHT MARK */
+		default:
+			return "";
+	}
+}
+
 #ifndef HAVE_STRSEP
 /* code taken from glibc-2.2.1/sysdeps/generic/strsep.c */
 char* strsep (char **stringp, const char *delim) {
