@@ -163,7 +163,7 @@ int export_OPML_feedlist(const gchar *filename, gboolean internal) {
 	xmlDocPtr 	doc;
 	xmlNodePtr 	cur, opmlNode;
 	gint		error = 0;
-	int		old_umask;
+	int		old_umask = 0;
 
 	debug_enter("export_OPML_feedlist");
 	
@@ -192,7 +192,7 @@ int export_OPML_feedlist(const gchar *filename, gboolean internal) {
 		
 		if(internal)
 			old_umask = umask(077);
-			
+
 		if(-1 == xmlSaveFormatFileEnc(filename, doc, NULL, 1)) {
 			g_warning("Could not export to OPML file!!");
 			error = 1;
