@@ -158,11 +158,15 @@ static void favicon_download_4(feedPtr fp) {
 static void favicon_download_request_favicon_cb(struct request *request) {
 	feedPtr		fp = (feedPtr)request->user_data;
 	gboolean	success = FALSE;
-	
-	debug2(DEBUG_UPDATE, "icon download processing (%s, %d bytes)", request->source, request->size);
+
+	debug3(DEBUG_UPDATE, "icon download processing (%s, %d bytes, content type %s)", request->source, request->size, request->contentType);
 	fp->otherRequests = g_slist_remove(fp->otherRequests, request);
-	
-	if(NULL != request->data && request->size > 0) {
+
+	if(request->data && 
+	   request->size > 0 && 
+	   request->contentType /*&&*/
+	   /* the MIME type is wrong much too often, so we cannot check it... */
+	   /*(!strncmp("image", request->contentType, 5))*/) {
 		GdkPixbufLoader *loader = NULL;
 		GdkPixbuf *pixbuf = NULL;
 		GError		*err = NULL;
