@@ -525,7 +525,7 @@ void feed_schedule_update(feedPtr fp, gint flags) {
 	}
 	
 	if(feed_get_discontinued(fp)) {
-		ui_mainwindow_set_status_bar(_("The feed was discontinued. Liferea won't update it anymore!"));
+		ui_mainwindow_set_status_bar(_("The feed \"%s\" was discontinued. Liferea won't update it anymore!"), feed_get_title(fp));
 		return;
 	}
 	
