@@ -218,6 +218,7 @@ void item_free(itemPtr ip) {
 
 gchar *item_render(itemPtr ip) {
 	struct displayset	displayset;
+	const gchar		*htmlurl;
 	gchar			*buffer = NULL;
 	gchar			*tmp, *tmp2;
 	xmlChar			*tmp3;
@@ -232,14 +233,13 @@ gchar *item_render(itemPtr ip) {
 	/* Head table */
 	addToHTMLBufferFast(&buffer, HEAD_START);
 	/*  -- Feed line */
-	if(feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed) != NULL)
-		
-		tmp = g_markup_printf_escaped("<span class=\"feedlink\"><a href=\"%s\">%s</a></span>",
-									 feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed),
-									 feed_get_title((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed));
+	htmlurl = feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed);
+	if(htmlurl != NULL)	
+		tmp = g_markup_printf_escaped("<span class=\"feedlink\"><a href=\"%s\">%s</a></span>", htmlurl,
+		                              feed_get_title((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed));
 	else
 		tmp = g_markup_printf_escaped("<span class=\"feedlink\">%s</span>",
-			              feed_get_title((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed));
+		                              feed_get_title((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed));
 
 	tmp2 = g_strdup_printf(HEAD_LINE, _("Feed:"), tmp);
 	g_free(tmp);
@@ -256,11 +256,11 @@ gchar *item_render(itemPtr ip) {
 
 	if(NULL != tmp) {
 		tmp2 = common_create_cache_filename("cache" G_DIR_SEPARATOR_S "favicons", tmp, "png");
-		tmp = g_strdup_printf("<a href=\"%s\"><img class=\"favicon\" src=\"file://%s\"></a>", feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed), tmp2);
+		tmp = g_strdup_printf("<a href=\"%s\"><img class=\"favicon\" src=\"file://%s\"></a>", htmlurl?htmlurl:"", tmp2);
 		g_free(tmp2);
 	} else {
 		tmp2 = g_strdup(PACKAGE_DATA_DIR G_DIR_SEPARATOR_S PACKAGE G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S "available.png");
-		tmp = g_strdup_printf("<a href=\"%s\"><img class=\"favicon\" src=\"file://%s\"></a>", feed_get_html_url((NULL == ip->sourceFeed)?ip->fp:ip->sourceFeed), tmp2);
+		tmp = g_strdup_printf("<a href=\"%s\"><img class=\"favicon\" src=\"file://%s\"></a>", htmlurl?htmlurl:"", tmp2);
 		g_free(tmp2);
 	}
 	tmp3 = g_markup_escape_text((item_get_title(ip) != NULL)?item_get_title(ip):_("[No title]"), -1);
@@ -427,6 +427,7 @@ itemPtr item_parse_cache(xmlDocPtr doc, xmlNodePtr cur) {
 			ip->metadata = metadata_parse_xml_nodes(doc, cur);
 		
 		g_free(tmp);	
+		tmp = NULL;
 		cur = cur->next;
 	}
 
