@@ -27,6 +27,12 @@
 #  include <config.h>
 #endif
 
+#ifdef USE_DBUS
+#define DBUS_API_SUBJECT_TO_CHANGE
+#include <dbus/dbus.h>
+#include <dbus/dbus-glib.h>
+#endif
+
 #include <gtk/gtk.h>
 #include <locale.h> /* For setlocale */
 
@@ -113,6 +119,7 @@ static gboolean main_lock() {
 			retval = -2;
 			goto main_lock_out;
 		}
+		memset(tmp, 0, 300);
 		if ((len = readlink(filename2, tmp, 299)) == -1) {
 			retval = -2; /* Unreadable link, or not a link */
 			goto main_lock_out;
@@ -188,6 +195,9 @@ int main(int argc, char *argv[]) {
 	g_set_prgname("liferea");
 	gtk_set_locale();
 	g_thread_init(NULL);
+#ifdef USE_DBUS
+	dbus_g_thread_init();
+#endif
 	gtk_init(&argc, &argv);
 	
 	/* parse arguments  */
@@ -324,7 +334,6 @@ gboolean on_quit(GtkWidget *widget, GdkEvent *event, gpointer user_data) {
 	/* unplug */
 	session_end();
 #endif
-	
 	gtk_main_quit();
 	main_unlock();
 	
