@@ -24,10 +24,9 @@
 
 char * UIDejunk (char * feed_description);
 char * WrapText (char * text, int width);
-void *zlib_uncompress(void *in_buf, int in_size, int *out_size, int voodoo_magic);
-void *gzip_uncompress(void *in_buf, int in_size, int *out_size);
 char *base64encode(char const *inbuf, unsigned int inbuf_size);
-void CleanupString (char * string);
+char* decodechunked(char * chunked, unsigned int *inputlen);
+void CleanupString (char * string, int tidyness);
 
 struct gzip_header {
 	unsigned char magic[2];
