@@ -56,6 +56,8 @@
 #include <assert.h>
 
 #include <libxml/uri.h>
+#include <arpa/nameser.h>
+#include <resolv.h>
 
 #include "conversions.h"
 #include "net-support.h"
@@ -138,6 +140,8 @@ int NetConnect (int * my_socket, char * host, struct feed_request * cur_ptr, enu
 	int ret;
 	struct addrinfo hints;
 	struct addrinfo *res = NULL, *ai;
+	char *realhost;
+	char port_str[9];
 	
 	/*
 	if (!suppressoutput) {
@@ -160,27 +164,31 @@ int NetConnect (int * my_socket, char * host, struct feed_request * cur_ptr, enu
 	hints.ai_socktype = SOCK_STREAM;
 	hints.ai_protocol = IPPROTO_TCP;
 	if (proxyport == 0) {
-		char *realhost, port_str[9];
-
 		realhost = strdup(host);
 		if (sscanf (host, "%[^:]:%8s", realhost, port_str) != 2) {
 			strcpy(port_str, "80");
 		}
-		ret = getaddrinfo(realhost, port_str, &hints, &res);
-		free(realhost);
 	} else {
-		char port_str[6];
-		
 		snprintf(port_str, sizeof(port_str), "%d", proxyport);
-		ret = getaddrinfo(proxyname, port_str, &hints, &res);
+		realhost = strdup(proxyname);
 	}
 	
+	ret = getaddrinfo(realhost, port_str, &hints, &res);
+	
 	if (ret != 0 || res == NULL) {
 		if (res != NULL)
 			freeaddrinfo(res);
-		cur_ptr->netio_error = NET_ERR_HOST_NOT_FOUND;
-		return -1;
+		res_init(); /* Reset the resolver */
+		ret = getaddrinfo(realhost, port_str, &hints, &res);
+		if (ret != 0 || res == NULL) {
+			if (res != NULL)
+				freeaddrinfo(res);
+			cur_ptr->netio_error = NET_ERR_HOST_NOT_FOUND;
+			free(realhost);
+			return -1;
+		}
 	}
+	free(realhost);
 	
 	for (ai = res; ai != NULL; ai = ai->ai_next) {
 		/* Create a socket. */
@@ -261,9 +269,12 @@ int NetConnect (int * my_socket, char * host, struct feed_request * cur_ptr, enu
 	
 	/* If proxyport is 0 we didn't execute the if http_proxy statement in main
 	   so there is no proxy. On any other value of proxyport do proxyrequests instead. */
-	if (proxyport == 0) {
-		/* Lookup remote IP. */
-		remotehost = gethostbyname (realhost);
+	remotehost = gethostbyname (proxyport?proxyname:realhost);
+	
+	/* Lookup remote IP. */
+	if (remotehost == NULL) {
+		res_init(); /* Reset resolver & force reread of resolv.conf */
+		remotehost = gethostbyname (proxyname);
 		if (remotehost == NULL) {
 			close (*my_socket);
 			free (realhost);
@@ -566,7 +577,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed_request * cu
 					if (strncasecmp (netbuf, "Location", 8) == 0) {
 						redirecttarget = strdup (netbuf);
 						freeme = redirecttarget;
-						
+
 						/* Remove trailing \r\n from line. */
 						redirecttarget[strlen(redirecttarget)-2] = 0;
 						
@@ -581,7 +592,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed_request * cu
 							fclose (stream);
 							return NULL;
 						}
-						
+
 						/* Location must start with "http", otherwise switch on quirksmode. */
 						if (strncmp(redirecttarget, "http", 4) != 0)
 							quirksmode = 1;
@@ -935,7 +946,7 @@ char * NetIO (int * my_socket, char * host, char * url, struct feed_request * cu
 	/* If inflate==1 we need to decompress the content.. */
 	if (inflate == 1) {
 		/* gzipinflate */
-		if (jg_gzip_uncompress (body, length, (void **)&inflatedbody, &len) != 0) {
+		if (jg_gzip_uncompress (body, length, &inflatedbody, &len) != 0) {
 			free (body);
 			cur_ptr->netio_error = NET_ERR_GZIP_ERR;
 			return NULL;
