@@ -1,5 +1,5 @@
 /*
- *  $Id: zlib_interface.h,v 1.1 2004/11/01 01:49:05 llando Exp $
+ *  $Id: zlib_interface.h,v 1.1.20.1 2006/01/23 20:45:05 t98502 Exp $
  *  JaguarFoundation
  *  Copyright © 2004 René Puls <http://purl.org/net/kianga/>
  *
@@ -38,7 +38,7 @@ int jg_zlib_uncompress(void const *in_buf, int in_size,
                        void **out_buf_ptr, int *out_size,
                        int gzip);   
 
-int jg_gzip_uncompress(void const *in_buf, int in_size,
+int jg_gzip_uncompress(char const *in_buf, int in_size,
                        void **out_buf_ptr, int *out_size);
 
 #endif
