@@ -1,7 +1,7 @@
 /**
  * @file pie_feed.c Atom/Echo/PIE 0.2/0.3 channel parsing
  * 
- * Copyright (C) 2003, 2004 Lars Lindner <lars.lindner@gmx.net>
+ * Copyright (C) 2003-2006 Lars Lindner <lars.lindner@gmx.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -84,15 +84,15 @@ gchar* pie_parse_content_construct(xmlNodePtr cur) {
 
 		/* This that need to be de-encoded and should not contain sub-tags.*/
 		if (NULL == type || (
-						 !strcmp(type, "TEXT") ||
+						 !g_strcasecmp(type, "TEXT") ||
 						 !strcmp(type, "text/plain") ||
-						 !strcmp(type, "HTML") ||
+						 !g_strcasecmp(type, "HTML") ||
 						 !strcmp(type, "text/html"))) {
 			ret = utf8_fix(xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, 1));
 			/* Next are things that contain subttags */
 		} else if((NULL == type) ||
 				/* HTML types */
-				!strcmp(type, "XHTML") ||
+				!g_strcasecmp(type, "XHTML") ||
 				!strcmp(type, "application/xhtml+xml")) {
 			/* Text types */
 			ret = extractHTMLNode(cur, TRUE);
