@@ -82,7 +82,7 @@ void ui_enclosure_init(void) {
 }
 
 /* saves the enclosure type configurations to disk */
-void ui_enclosure_save(void) {
+void ui_enclosure_save_config(void) {
 	xmlDocPtr	doc;
 	xmlNodePtr	root, cur;
 	encTypePtr	etp;
@@ -128,7 +128,7 @@ void ui_enclosure_remove_type(gpointer type) {
 	g_free(((encTypePtr)type)->mime);
 	g_free(((encTypePtr)type)->extension);
 	g_free(type);
-	ui_enclosure_save();
+	ui_enclosure_save_config();
 }
 
 void ui_enclosure_change_type(gpointer type) {
@@ -172,40 +172,36 @@ static gpointer ui_enclosure_exec(gpointer data) {
 }
 
 /* etp is optional, if it is missing we are in save mode */
-void ui_enclosure_download(encTypePtr etp, gchar *url, gchar *filename) {
+void ui_enclosure_download(encTypePtr etp, const gchar *url, const gchar *filename) {
 	encJobPtr	ejp;
 	gchar *filenameQ, *urlQ;
+
 	/* prepare job structure */
 	ejp = g_new0(struct encJob, 1);
-	ejp->filename = filename;
+	ejp->filename = g_strdup(filename);
 
 	filenameQ = g_shell_quote(filename);
 	urlQ = g_shell_quote(url);
 	ejp->download = g_strdup_printf(prefs_get_download_cmd(), filenameQ, urlQ);
+	if(NULL != etp)
+		ejp->run = g_strdup_printf("%s %s", etp->cmd, filenameQ);
+
 	g_free(filenameQ);
 	g_free(urlQ);
 	
-	if(NULL != etp)
-		ejp->run = g_strdup_printf("%s %s", etp->cmd, filename);
-
 	debug2(DEBUG_UPDATE, "downloading %s to %s...\n", url, filename);
 
 	/* free now unnecessary stuff */
 	if((NULL != etp) && (FALSE == etp->permanent))
 		ui_enclosure_remove_type(etp);
-	g_free(url);
 	
 	g_thread_create(ui_enclosure_exec, ejp, FALSE, NULL);
 }
 
 /* opens a popup menu for the given link */
-void ui_enclosure_new_popup(gchar *url) {
-	gchar	*enclosure;
+void ui_enclosure_new_popup(const gchar *url) {
 	
-	if(NULL != (enclosure = xmlURIUnescapeString(url + strlen(ENCLOSURE_PROTOCOL "load?"), 0, NULL))) {
-		gtk_menu_popup(ui_popup_make_enclosure_menu(enclosure), NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time());
-		g_free(enclosure);
-	}
+	gtk_menu_popup(ui_popup_make_enclosure_menu(url), NULL, NULL, NULL, NULL, 0, gtk_get_current_event_time());
 }
 
 static void on_selectcmdok_clicked(const gchar *filename, gpointer user_data) {
@@ -228,7 +224,7 @@ static void on_selectcmd_pressed(GtkButton *button, gpointer user_data) {
 	
 	utfname =  gtk_entry_get_text(GTK_ENTRY(lookup_widget(dialog,"enc_cmd_entry")));
 	if(NULL != (name = g_filename_from_utf8(utfname, -1, NULL, NULL, NULL))) {
-		ui_choose_file(_("Choose File"), GTK_WINDOW(dialog), GTK_STOCK_OPEN, FALSE, on_selectcmdok_clicked, NULL, name, dialog);
+		ui_choose_file(_("Choose File"), GTK_WINDOW(dialog), GTK_STOCK_OPEN, FALSE, on_selectcmdok_clicked, name, NULL, dialog);
 		g_free(name);
 	}
 }
@@ -259,7 +255,7 @@ static void on_adddialog_response(GtkDialog *dialog, gint response_id, gpointer
 		if(TRUE == new)
 			types = g_slist_append(types, etp);
 
-		ui_enclosure_save();		
+		ui_enclosure_save_config();		
 
 		/* now we have ensured an existing type configuration and
 		   can launch the URL for which we configured the type */
@@ -298,8 +294,30 @@ static void ui_enclosure_add(encTypePtr type, gchar *url, gchar *typestr) {
 	
 }
 
+/**
+ * Download an enclosure at "url" and save it to "filename". If
+ * filename is NULL, then a filename will be automatically generated
+ * based on the URL.
+ */
+
+void ui_enclosure_save(encTypePtr type, const gchar *url, const gchar *filename) {
+	
+	g_assert(url != NULL);
+	
+	if(NULL == filename) {
+		/* build filename from last part of URL and make it begin with
+		   the default enclosure save path */
+		if(NULL == (filename = strrchr(url, '/')))
+			filename = url;
+		else
+			filename++;
+		filename = g_strdup_printf("%s%s%s", getStringConfValue(ENCLOSURE_DOWNLOAD_PATH), G_DIR_SEPARATOR_S, filename);
+	}
+	ui_enclosure_download(type, url, filename);
+}
+
 void on_popup_open_enclosure(gpointer callback_data, guint callback_action, GtkWidget *widget) {
-	gchar		*typestr, *filename, *url = (gchar *)callback_data;
+	gchar		*typestr, *url = (gchar *)callback_data;
 	gboolean	found = FALSE, mime = FALSE;
 	encTypePtr	etp = NULL;
 	GSList		*iter;
@@ -338,21 +356,16 @@ void on_popup_open_enclosure(gpointer callback_data, guint callback_action, GtkW
 		iter = g_slist_next(iter);
 	}
 	
-	if(TRUE == found) {
-		if(NULL == (filename = strrchr(url, '/')))
-			filename = g_strdup(url + 1);
-
-		filename = g_strdup_printf("%s%s%s", getStringConfValue(ENCLOSURE_DOWNLOAD_PATH), G_DIR_SEPARATOR_S, filename);
-		ui_enclosure_download(etp, url, filename);
-	} else {
+	if(TRUE == found)
+		ui_enclosure_save(etp, url, NULL);
+	else
 		ui_enclosure_add(NULL, url, g_strdup(typestr));
-	}
 		
 	g_free(typestr);
 }
 
 static void on_encsave_clicked(const gchar *filename, gpointer user_data) {
-	GtkWidget	*dialog = (GtkWidget *)user_data;
+	/* GtkWidget	*dialog = (GtkWidget *)user_data;*/
 	gchar		*url = (gchar *)user_data;
 	gchar		*utfname;
 	
@@ -360,7 +373,8 @@ static void on_encsave_clicked(const gchar *filename, gpointer user_data) {
 		return;
 
 	utfname = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
-	ui_enclosure_download(NULL, url, utfname);
+	ui_enclosure_save(NULL, url, utfname);
+	g_free(utfname);
 }
 
 void on_popup_save_enclosure(gpointer callback_data, guint callback_action, GtkWidget *widget) {
@@ -372,5 +386,5 @@ void on_popup_save_enclosure(gpointer callback_data, guint callback_action, GtkW
 	else
 		filename = callback_data;
 		
-	ui_choose_file(_("Choose File"), GTK_WINDOW(mainwindow), GTK_STOCK_SAVE_AS, TRUE, on_encsave_clicked, filename, NULL, callback_data);
+	ui_choose_file(_("Choose File"), GTK_WINDOW(mainwindow), GTK_STOCK_SAVE_AS, TRUE, on_encsave_clicked, NULL, filename, callback_data);
 }
