@@ -621,7 +621,7 @@ void ui_feedlist_add(folderPtr parent, nodePtr node, gint position) {
 
 void ui_feedlist_new_subscription(const gchar *source, const gchar *filter, gint flags) {
 	feedPtr			fp;
-	gchar			*tmp;
+	gchar			*tmp, *uri;
 	int			pos;
 	folderPtr		parent;
 	
@@ -633,8 +633,10 @@ void ui_feedlist_new_subscription(const gchar *source, const gchar *filter, gint
 	g_free(tmp);
 	
 	g_assert(source);
-	tmp = g_strdup(source);
-	g_strstrip(tmp);
+	uri = g_strdup(source);
+	g_strstrip(uri);
+	
+	tmp = uri;	
 	if(tmp == strstr(tmp, FEED_PROTOCOL_PREFIX))
 		tmp += strlen(FEED_PROTOCOL_PREFIX);
 
@@ -650,7 +652,7 @@ void ui_feedlist_new_subscription(const gchar *source, const gchar *filter, gint
 	feed_schedule_update(fp, flags | FEED_REQ_PRIORITY_HIGH | FEED_REQ_DOWNLOAD_FAVICON | FEED_REQ_AUTH_DIALOG);
 	
 	/*ui_show_error_box(_("The newly created feed's type could not be detected! Please check if the source really points to a resource provided in one of the supported syndication formats"));*/
-	g_free(tmp);
+	g_free(uri);
 	
 	debug_exit("ui_feedlist_new_subscription");
 }
