@@ -58,15 +58,15 @@ static itemPtr ui_itemlist_get_selected();
 
 /* sort function for the item list date column */
 static gint timeCompFunc(GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer user_data) {
-	time_t	timea, timeb;
-	double diff;
+	gulong	timea, timeb;
+	double	diff;
 	
 	g_assert(model != NULL);
 	g_assert(a != NULL);
 	g_assert(b != NULL);
 	gtk_tree_model_get(model, a, IS_TIME, &timea, -1);
 	gtk_tree_model_get(model, b, IS_TIME, &timeb, -1);
-	diff = difftime(timeb,timea);
+	diff = difftime((time_t)timeb, (time_t)timea);
 	
 	if (diff < 0)
 		return 1;
@@ -107,7 +107,7 @@ GtkTreeStore * ui_itemlist_get_tree_store(void) {
 		                               G_TYPE_ULONG,
 		                               G_TYPE_STRING, 
 		                               G_TYPE_STRING,
-									   G_TYPE_POINTER,
+		                               G_TYPE_POINTER,
 		                               GDK_TYPE_PIXBUF,
 		                               G_TYPE_ULONG,
 		                               GDK_TYPE_PIXBUF);
@@ -741,33 +741,36 @@ gboolean on_itemlist_button_press_event(GtkWidget *widget, GdkEventButton *event
 	if(!gtk_tree_view_get_path_at_pos(GTK_TREE_VIEW(treeview), event->x, event->y, &path, NULL, NULL, NULL))
 		return FALSE;
 
-	gtk_tree_model_get_iter(GTK_TREE_MODEL(ui_itemlist_get_tree_store()), &iter, path);
+	if(gtk_tree_model_get_iter(GTK_TREE_MODEL(ui_itemlist_get_tree_store()), &iter, path))
+		ip = ui_itemlist_get_item_from_iter(&iter);
+		
 	gtk_tree_path_free(path);
-	
-	ip = ui_itemlist_get_item_from_iter(&iter);
 
-	eb = (GdkEventButton*)event; 
-	switch(eb->button) {
-		case 2:
-			/* depending on the column middle mouse click toggles flag or read status
-			   We depent on the fact that the state column is the first!!! 
-			   code inspired by the GTK+ 2.0 Tree View Tutorial at:
-			   http://scentric.net/tutorial/sec-misc-get-renderer-from-click.html */
-			if(NULL != (column = gtk_tree_view_get_column(GTK_TREE_VIEW(treeview), 0))) {
-				g_assert(NULL != column);
-				if(event->x <= column->width)
-					itemlist_toggle_flag(ip);
-				else
-					itemlist_toggle_read_status(ip);
-			}
-			return TRUE;
-			break;
-		case 3:
-			ui_itemlist_select(iter);
-			gtk_menu_popup(make_item_menu(ip), NULL, NULL, NULL, NULL, eb->button, eb->time);
-			return TRUE;
-			break;
-	}	
+
+	if(ip) {
+		eb = (GdkEventButton*)event; 
+		switch(eb->button) {
+			case 2:
+				/* depending on the column middle mouse click toggles flag or read status
+				   We depent on the fact that the state column is the first!!! 
+				   code inspired by the GTK+ 2.0 Tree View Tutorial at:
+				   http://scentric.net/tutorial/sec-misc-get-renderer-from-click.html */
+				if(NULL != (column = gtk_tree_view_get_column(GTK_TREE_VIEW(treeview), 0))) {
+					g_assert(NULL != column);
+					if(event->x <= column->width)
+						itemlist_toggle_flag(ip);
+					else
+						itemlist_toggle_read_status(ip);
+				}
+				return TRUE;
+				break;
+			case 3:
+				ui_itemlist_select(iter);
+				gtk_menu_popup(make_item_menu(ip), NULL, NULL, NULL, NULL, eb->button, eb->time);
+				return TRUE;
+				break;
+		}
+	}
 	return FALSE;
 }
 
