@@ -431,9 +431,11 @@ void ui_mainwindow_update_onlinebtn(void) {
 	if(download_is_online()) {
 		ui_mainwindow_set_status_bar(_("Liferea is now online"));
 		gtk_image_set_from_pixbuf(GTK_IMAGE(widget), icons[ICON_ONLINE]);
+		atk_object_set_name(gtk_widget_get_accessible(widget), _("Work Offline"));
 	} else {
 		ui_mainwindow_set_status_bar(_("Liferea is now offline"));
 		gtk_image_set_from_pixbuf(GTK_IMAGE(widget), icons[ICON_OFFLINE]);
+		atk_object_set_name(gtk_widget_get_accessible(widget), _("Work Online"));
 	}
 }
 
