@@ -150,7 +150,7 @@ void download_process(struct request *request) {
 		if(!strncmp(filename, "file://",7))
 			filename += 7;
 		
-		if(anchor = strchr(filename, '#'))
+		if(NULL != (anchor = strchr(filename, '#')))
 			*anchor = 0;	 /* strip anchors from filenames */
 
 		if(g_file_test(filename, G_FILE_TEST_EXISTS)) {
@@ -189,6 +189,7 @@ void download_process(struct request *request) {
 			request->data = tmp;
 			request->size = len;
 		}
+		g_free(cmd);
 	}
 }
 
@@ -238,7 +239,7 @@ void download_init(void) {
 		count = DEFAULT_UPDATE_THREAD_CONCURRENCY;
 	
 	for(i = 0; i < count; i++)
-		g_thread_create(download_thread_main, (void *)(i == 0), FALSE, NULL);
+		g_thread_create(download_thread_main, GINT_TO_POINTER(i == 0), FALSE, NULL);
 
 	/* setup the processing of feed update results */
 	g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE,
@@ -250,7 +251,7 @@ void download_init(void) {
 
 static void *download_thread_main(void *data) {
 	struct request	*request;
-	gboolean	high_priority = (gboolean)data;
+	gboolean	high_priority = (gboolean)GPOINTER_TO_INT(data);
 
 	for(;;)	{	
 		/* block updating if we are offline */
